@@ -1,4 +1,5 @@
 from pyspark.sql import Column, DataFrame
+from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
 
 from spark_auto_mapper.data_types.column import AutoMapperDataTypeColumn
 from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
@@ -14,9 +15,14 @@ class AutoMapperBooleanDataType(AutoMapperDataTypeBase):
             else AutoMapperValueParser.parse_value(value)
 
     def get_column_spec(self, source_df: DataFrame) -> Column:
-        if isinstance(self.value, AutoMapperDataTypeColumn) \
+        if isinstance(self.value, AutoMapperDataTypeLiteral):
+            # parse the boolean here
+            column_spec = self.value.get_column_spec(source_df=source_df
+                                                     ).cast("boolean")
+            return column_spec
+        elif isinstance(self.value, AutoMapperDataTypeColumn) \
                 and dict(source_df.dtypes)[self.value.value] == "string":
-            # parse the amount here
+            # parse the boolean here
             column_spec = self.value.get_column_spec(source_df=source_df
                                                      ).cast("boolean")
             return column_spec
