@@ -1,4 +1,5 @@
 from pyspark.sql import Column, DataFrame
+from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
 
 from spark_auto_mapper.data_types.column import AutoMapperDataTypeColumn
 from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
@@ -14,6 +15,12 @@ class AutoMapperNumberDataType(AutoMapperDataTypeBase):
             else AutoMapperValueParser.parse_value(value)
 
     def get_column_spec(self, source_df: DataFrame) -> Column:
+        if isinstance(self.value, AutoMapperDataTypeLiteral) \
+                and isinstance(self.value.value, str):
+            # parse the amount here
+            column_spec = self.value.get_column_spec(source_df=source_df
+                                                     ).cast("int")
+            return column_spec
         if isinstance(self.value, AutoMapperDataTypeColumn) \
                 and dict(source_df.dtypes)[self.value.value] == "string":
             # parse the amount here
