@@ -1,3 +1,5 @@
+from typing import Union
+
 from pyspark.sql import Column, DataFrame
 from pyspark.sql.functions import substring_index
 
@@ -13,12 +15,13 @@ class AutoMapperSubstringByDelimiterDataType(AutoMapperTextLikeBase):
     substring_index performs a case-sensitive match when searching for delimiter.
     """
     def __init__(
-        self, column: AutoMapperDataTypeColumn, delimiter: str,
-        delimiter_count: int
+        self, column: Union[AutoMapperDataTypeColumn, AutoMapperTextLikeBase],
+        delimiter: str, delimiter_count: int
     ):
         super().__init__()
 
-        self.column: AutoMapperDataTypeColumn = column
+        self.column: Union[AutoMapperDataTypeColumn,
+                           AutoMapperTextLikeBase] = column
         self.delimiter: str = delimiter
         self.delimiter_count: int = delimiter_count
 
