@@ -8,6 +8,7 @@ from pyspark.sql.functions import lit
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.list import AutoMapperList
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+from spark_auto_mapper.helpers.spark_higher_order_functions import filter
 
 
 def test_auto_mapper_array_single_item_with_mapper(
@@ -42,7 +43,10 @@ def test_auto_mapper_array_single_item_with_mapper(
         print(f"{column_name}: {sql_expression}")
 
     assert str(sql_expressions["dst2"]) == str(
-        array(struct(lit("address1").alias("addr"))).alias("dst2")
+        filter(
+            array(struct(lit("address1").alias("addr"))),
+            lambda x: x.isNotNull()
+        ).alias("dst2")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
